==> haskell-profunctors-5.5.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 profunctors
version:              5.5.2
visibility:           public
id:                   profunctors-5.5.2-E6MVziCKW6w3zQo4LYU0dk
key:                  profunctors-5.5.2-E6MVziCKW6w3zQo4LYU0dk
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  7fe3ad0ecfc23c953d5ca59d11f428fd
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-8.10.2/site-local/profunctors-5.5.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/profunctors-5.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/profunctors-5.5.2
hs-libraries:         HSprofunctors-5.5.2-E6MVziCKW6w3zQo4LYU0dk
depends:
    base-4.14.1.0 base-orphans-0.8.3-1Cx1GLRXEnD58RPLiGNEeO
    bifunctors-5.5.7-Im1SaQ5Xu8jHVjyrpTNCmd
    comonad-5.0.6-fOGUTCPPz3Er9JwvHLk9Q
    contravariant-1.5.2-9cUYDQvrBi493NpHNvxLum
    distributive-0.6.2-HW6okj23SkGHiKo9leRqef
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.5.2-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 profunctors
version:              5.5.2
visibility:           public
id:                   profunctors-5.5.2-GWxnqFfQ55HxWb10mfvfh
key:                  profunctors-5.5.2-GWxnqFfQ55HxWb10mfvfh
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  298cb12f852e8a661f7d9d46d2057d60
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-8.10.2/site-local/profunctors-5.5.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/profunctors-5.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/profunctors-5.5.2
hs-libraries:         HSprofunctors-5.5.2-GWxnqFfQ55HxWb10mfvfh
depends:
    base-4.14.1.0 base-orphans-0.8.3-BGmHbketmBaEj7xM8Bozgl
    bifunctors-5.5.7-Kt6bcBZFJxbK48T6RjTu99
    comonad-5.0.6-4D6za4SJfPLAfRbRiHlWCo
    contravariant-1.5.2-9cUYDQvrBi493NpHNvxLum
    distributive-0.6.2-LiOUDS9yU0cKI8dgr7bcdL
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
